import java.io.IOException; 
import java.io.PrintWriter; 
import javax.servlet.ServletException; 
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpSession; 
import javax.servlet.http.HttpServletRequest; 
import javax.servlet.http.HttpServletResponse; 

/**
 * Reports number of times a given user has visited the page in the 
 * current session.
 *
 * @author  Computer Science E-259
 *
 * @throws IOException, ServletException
 */

public class Visits extends HttpServlet {

    public void doGet(HttpServletRequest request, 
                      HttpServletResponse response)
    throws IOException, ServletException
    {
        // output plain text
        response.setContentType("text/plain");

        // grab PrintWriter
        PrintWriter out = response.getWriter();

        // grab user parameter, else err
        String user = request.getParameter("user");
        if (user == null) 
            throw new ServletException("missing user parameter");

        // grab current session
        HttpSession sess = request.getSession();

        // grab user's number of visits from session; if null,
        // initialize to 0
        Integer visits = (Integer) sess.getAttribute(user);
        if (visits == null)
            visits = new Integer(0);

        // update session's count of user's number of visits
        sess.setAttribute(user, new Integer(visits.intValue() + 1));

        // say hello
        out.println("Hey, " + user + "!  " +
                    "What's it been, " + visits.intValue() + " time(s)?");
    } 
}
